{%- set ext_ip = "x.x.x.x" %}
{%- set internal_ip = "y.y.y.y" %}

haproxy: |
  global
    log /dev/log    local0
    log /dev/log    local1 notice
    chroot /var/lib/haproxy
    stats socket /run/haproxy/admin.sock mode 660 level admin expose-fd listeners
    stats timeout 30s
    user haproxy
    group haproxy
    daemon

    tune.ssl.default-dh-param 2048

    # Default SSL material locations
    ca-base /etc/ssl/certs
    crt-base /etc/ssl/private

    # Default ciphers to use on SSL-enabled listening sockets.
    # For more information, see ciphers(1SSL). This list is from:
    #  https://hynek.me/articles/hardening-your-web-servers-ssl-ciphers/
    # An alternative list with additional directives can be obtained from
    #  https://mozilla.github.io/server-side-tls/ssl-config-generator/?server=haproxy
    ssl-default-bind-ciphers ECDH+AESGCM:DH+AESGCM:ECDH+AES256:DH+AES256:ECDH+AES128:DH+AES:R$
    ssl-default-bind-options no-sslv3

  defaults
    log     global
    mode    http
    option  httplog
    option  dontlognull
    timeout connect 5000
    timeout client  50000
    timeout server  50000
    timeout tunnel  1800s
    errorfile 400 /etc/haproxy/errors/400.http
    errorfile 403 /etc/haproxy/errors/403.http
    errorfile 408 /etc/haproxy/errors/408.http
    errorfile 500 /etc/haproxy/errors/500.http
    errorfile 502 /etc/haproxy/errors/502.http
    errorfile 503 /etc/haproxy/errors/503.http
    errorfile 504 /etc/haproxy/errors/504.http

    option forwardfor
    option forceclose

  frontend http-in
    bind {{ext_ip}}:80

    # Conditions for acme challenges
    acl is_acme path_beg /.well-known/acme-challenge/

    # Redirect all of http to https
    redirect scheme https code 301 if !is_acme
    use_backend acme if is_acme

  backend acme
    server acme1 127.0.0.1:8081

  frontend https-in
    bind {{ext_ip}}:443 ssl crt ./ alpn h2,http/1.1

    # our-company.com
    acl is_company_domain ssl_fc_sni -i our-company.com
    use_backend company_site if is_company_domain

  backend company_site
    # HSTS (15552000 seconds = 6*30 days)
    http-response set-header Strict-Transport-Security max-age=15552000
    server site1 {{internal_ip}}
