#
# Certbot with helping NGINX (installed and configured in default locations),
# when host uses HAProxy.
#
# Acme responses are served on 127.0.0.1:8081 from a webroot /var/www/acme.
# PEM files with key and fullchain are placed into /etc/ssl/private.
#
# NGINX installation and setting file is global, removing an option of running
# it in a system. This can be changed in the future to something simpler and
# lightweight.
#
# When HAProxy is proxying acme, add to its config the following or analog:
# ```
# frontend http-in
#   bind <ip>:80
#   acl is_acme path_beg /.well-known/acme-challenge/
#   use_backend acme if is_acme
# backend acme
#   server acme1 127.0.0.1:8081
# ```
#

certbot:
  pkg.installed

/var/www/acme:
  file.directory

{%- if "nginx" in pillar %}

/etc/letsencrypt/renewal-hooks/deploy/1.sh:
  file.managed:
    - source: salt://certbot/with-nginx/hooks/deploy.sh
    - makedirs: True
    - mode: 544

/root/bin/cert-add:
  file.managed:
    - source: salt://certbot/with-nginx/cert-add.sh
    - makedirs: True
    - mode: 544

{%- elif "haproxy" in pillar %}

nginx:
  pkg.installed

/etc/letsencrypt/renewal-hooks/pre/1.sh:
  file.managed:
    - source: salt://certbot/with-haproxy/hooks/pre.sh
    - makedirs: True
    - mode: 544

/etc/letsencrypt/renewal-hooks/post/1.sh:
  file.managed:
    - source: salt://certbot/with-haproxy/hooks/post.sh
    - makedirs: True
    - mode: 544

/etc/letsencrypt/renewal-hooks/deploy/1.sh:
  file.managed:
    - source: salt://certbot/with-haproxy/hooks/deploy.sh
    - makedirs: True
    - mode: 544

/etc/nginx/nginx.conf:
  file.managed:
    - makedirs: True
    - source: salt://certbot/with-haproxy/nginx.conf

/root/bin/cert-add:
  file.managed:
    - source: salt://certbot/with-haproxy/cert-add.sh
    - makedirs: True
    - mode: 544

/root/bin/cert-remove:
  file.managed:
    - source: salt://certbot/with-haproxy/cert-remove.sh
    - makedirs: True
    - mode: 544

{%- else %}

No app set for work with certbot:
  file.no_such_method:
    - throw error here

{%- endif %}
